@@ -1,5 +1,4 @@
 # frozen_string_literal: true
-# encoding: utf-8
 
 require 'test_helper'
 
@@ -8,14 +7,14 @@ require 'test_helper'
 #
 class TestIgnoredFilesWithEscapedPath < Test::Unit::TestCase
   def test_ignored_files_with_non_ascii_filename
-    in_temp_dir do |path|
+    in_temp_dir do |_path|
       create_file('README.md', '# My Project')
       `git init`
       `git add .`
       `git config --local core.safecrlf false` if Gem.win_platform?
       `git commit -m "First Commit"`
       create_file('my_other_file_☠', "First Line\n")
-      create_file(".gitignore", "my_other_file_☠")
+      create_file('.gitignore', 'my_other_file_☠')
       files = Git.open('.').ignored_files
       assert_equal(['my_other_file_☠'].sort, files)
     end
